@@ -1,7 +1,13 @@
 from zope.i18nmessageid import MessageFactory
+from Products.CMFCore.permissions import setDefaultRoles
 from Products.Archetypes import atapi
 from Products.CMFCore import utils
-from Products.PFGVerkkomaksut.config import ADD_PERMISSIONS, PROJECTNAME
+
+PROJECTNAME = "PFGVerkkomaksut"
+ADD_PERMISSIONS = {
+    "PFGVerkkomaksut" : "Add PFGVerkkomaksut",
+}
+setDefaultRoles("Add PFGVerkkomaksut", ('Manager',))
 
 PFGVerkkomaksutMessageFactory = MessageFactory(PROJECTNAME)
 
