@@ -3,12 +3,12 @@ from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.CMFCore.utils import getToolByName
 
-#class PFGVerkkomaksutView(BrowserView):
+class PFGVerkkomaksutView(BrowserView):
 
-#    template = ViewPageTemplateFile('templates/verkkomaksut.pt')
+    template = ViewPageTemplateFile('templates/verkkomaksut.pt')
 
-#    def __call__(self):
-#        return self.template()
+    def __call__(self):
+        return self.template()
 
 class PFGVerkkomaksutSuccessView(BrowserView):
 
